@@ -153,7 +153,7 @@ generic.predict.rfsrc <-
   }
     else {
       object.version <- as.integer(unlist(strsplit(object$version, "[.]")))
-      installed.version <- as.integer(unlist(strsplit("3.4.0", "[.]")))
+      installed.version <- as.integer(unlist(strsplit("3.4.1", "[.]")))
       minimum.version <- as.integer(unlist(strsplit("2.3.0", "[.]")))
       object.version.adj <- object.version[1] + (object.version[2]/10) + (object.version[3]/100)
       installed.version.adj <- installed.version[1] + (installed.version[2]/10) + (installed.version[3]/100)
@@ -182,7 +182,7 @@ generic.predict.rfsrc <-
         ## nothing 
       }
       else {##predict has requested rfq
-        class.relfrq <- table(object$yvar) / length(object$yvar)
+        class.relfrq <- prop.table(table(object$yvar))
       }
     }
     if (is.null(rfq)) {##predict  ambivalent about rfq
@@ -190,7 +190,7 @@ generic.predict.rfsrc <-
         ## nothing -> rfq = FALSE
       }
       else {##grow used rfq - use grow spec
-        class.relfrq <- table(object$yvar) / length(object$yvar)
+        class.relfrq <- prop.table(table(object$yvar))
         rfq <- TRUE
       }
     }
