@@ -163,7 +163,13 @@ typedef unsigned long ulong;
 #define RF_OPT_LO_GROW   101  
 #define RF_OPT_HI_GROW   102  
 #define RF_CPU_TIME      103  
-#define RF_SEXP_CNT      104  
+#define RF_TN_OCNT       104  
+#define RF_TN_ICNT       105  
+#define RF_OMBR_ID       106 
+#define RF_IMBR_ID       107 
+#define RF_OOB_SZ        108 
+#define RF_IBG_SZ        109 
+#define RF_SEXP_CNT      110  
 #define RF_SEXP_ASCII_SIZE 16
 #define OPT_FENS      0x00000001 
 #define OPT_OENS      0x00000002 
@@ -395,11 +401,13 @@ struct terminal {
   double weight;
   unsigned int membrCount;
   unsigned int *membrStream;
-  unsigned int *membrIndx;
   unsigned int inbagProxy;
   double timeCutLeft;
   double timeCutRight;
   double *localEmpiricalHazard;
+  uint repMembrSizeAlloc, oobMembrSizeAlloc, ibgMembrSizeAlloc;
+  uint repMembrSize, oobMembrSize, ibgMembrSize;
+  uint *repMembrIndx, *oobMembrIndx, *ibgMembrIndx;
 };
 typedef struct leafLinkedObj LeafLinkedObj;
 struct leafLinkedObj {
@@ -411,6 +419,7 @@ struct leafLinkedObj {
   uint nodeID;
   uint ibgMembrCount;
   uint allMembrCount;
+  uint oobMembrCount;
 };
 typedef struct leafLinkedObjSimple LeafLinkedObjSimple;
 struct leafLinkedObjSimple {
@@ -1895,21 +1904,6 @@ void unstackTreeObjectsPtrOnly(uint treeID);
 void stackForestObjectsAuxOnly(char mode);
 void unstackForestObjectsAuxOnly(char mode);
 void unstackAuxStatisticalStructures(char mode);
-void stackTNQualitativeObjectsKnown(char     mode,
-                                    uint   **pRF_RMBR_ID_,
-                                    uint   **pRF_AMBR_ID_,
-                                    uint   **pRF_TN_RCNT_,
-                                    uint   **pRF_TN_ACNT_);
-void stackTNQualitativeObjectsUnknown(char     mode,
-                                      uint   **pRF_TN_RCNT_,
-                                      uint   **pRF_TN_ACNT_);
-void stackTNQuantitativeForestObjectsPtrOnly(char mode);
-void unstackTNQuantitativeForestObjectsPtrOnly(char mode);
-void stackTNQuantitativeTreeObjectsPtrOnly(uint treeID);
-void unstackTNQuantitativeTreeObjectsPtrOnly(uint treeID);
-void saveTNQuantitativeTreeObjects(uint treeID);
-void stackTNQuantitativeForestObjectsOutput(char mode);
-void writeTNQuantitativeForestObjectsOutput(char mode);
 void restackTermListAndQualitativeObjectsUnknown(uint treeID, uint length);
 void verifyAndRegisterCustomSplitRules(void);
 extern void registerCustomFunctions(void);
@@ -1926,6 +1920,26 @@ void allocateAuxiliaryInfo(char   targetFlag,
 uint getAuxDim(char flag, int *dim, uint preIndex, uint postIndex);
 void unstackAuxiliaryInfoAndList(char targetFlag, SNPAuxiliaryInfo **list, uint count);
 void memoryCheck(void);
+void stackTNQualitativeObjectsKnown(char     mode,
+                                    uint   **pRF_RMBR_ID_,
+                                    uint   **pRF_AMBR_ID_,
+                                    uint   **pRF_TN_RCNT_,
+                                    uint   **pRF_TN_ACNT_,
+                                    uint   **pRF_OOB_SZ_,
+                                    uint   **pRF_IBG_SZ_);
+void stackTNQualitativeObjectsUnknown(char     mode,
+                                      uint   **pRF_TN_RCNT_,
+                                      uint   **pRF_TN_ACNT_,
+                                      uint   **pRF_TN_OCNT_,
+                                      uint   **pRF_TN_ICNT_);
+void stackTNQuantitativeForestObjectsPtrOnly(char mode);
+void unstackTNQuantitativeForestObjectsPtrOnly(char mode);
+void stackTNQuantitativeTreeObjectsPtrOnly(uint treeID);
+void unstackTNQuantitativeTreeObjectsPtrOnly(uint treeID);
+void saveTNQuantitativeTreeObjects(uint treeID);
+void stackTNQuantitativeForestObjectsOutput(char mode);
+void writeTNQuantitativeForestObjectsOutput(char mode);
+void stackTNQualitativeObjectsUnknownMembership(char   mode, uint **pRF_OMBR_ID_, uint **pRF_IMBR_ID_);
 void stackLocksOpenMP(char mode);
 void unstackLocksOpenMP(char mode);
 void stackLocksPosix(char mode);
